"""meteoswiss - Library to get data from meteo swiss"""

__version__ = '0.0.11'
__author__ = 'websylv <div@webhu.org>'
__all__ = []

from .get_all_stations import get_all_stations
from .get_all_stations import get_closest_station
from .get_current_condition import get_current_condition
from .misc import get_wind_bearing
from .get_forecast import get_forecast



from bs4 import BeautifulSoup
import json
import requests
def get_forecast(postCode):
    baseUrl = 'https://www.meteosuisse.admin.ch'

    s = requests.Session()
    #Forcing headers to avoid 500 error when downloading file
    s.headers.update({"Accept":"text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8",
                "Accept-Encoding":"gzip, deflate, sdch",'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/1337 Safari/537.36'})

    tmp = s.get("https://www.meteosuisse.admin.ch/home/actualite/infos.html?ort=%s"%postCode)

    soup = BeautifulSoup(tmp.text,features="html.parser")
    widgetHtml = soup.find_all("section",{"id": "weather-widget"})
    jsonUrl = widgetHtml[0].get("data-json-url")
    jsonDataFile = str.split(jsonUrl,'/')[-1]
    newJsonDataFile = str(postCode)+"00.json"
    jsonUrl = str(jsonUrl).replace(jsonDataFile,newJsonDataFile)
    jsonData = s.get(baseUrl + jsonUrl)
    jsonData.encoding = "utf8"
    jsonDataTxt = jsonData.text

    jsonObj = json.loads(jsonDataTxt)

    return jsonObj


import requests
import re
import geopy
import geopy.distance

def get_all_stations():
    s = requests.Session()
    tmp = s.get("https://data.geo.admin.ch/ch.meteoschweiz.messwerte-aktuell/info/VQHA80_fr.txt")
    descriptionLines = tmp.text.split('\n')
    cordinatesFound = False
    stationList = {}
    for line in descriptionLines:
        if not cordinatesFound :
            if(re.match(r"Stations\sCoordinates", line)):
                cordinatesFound = True
        else:
            if(re.match(r"^[A-Z]{3}\s+",line)):
                
                lineParts = None
                lineParts = re.split(r'\s\s+',line)
               
                
                ## Saving station data to a dictionnary
                stationData = {}
                stationData["code"] = lineParts[0]
                stationData["name"] = lineParts[1]
                stationData["lat"] = lineParts[2].split("/")[1]
                stationData["lon"] = lineParts[2].split("/")[0]
                stationData["coordianteKM"] = lineParts[3]
                stationData["altitude"] = lineParts[4].strip()
                
                stationList[lineParts[0]] = stationData
                
    return stationList 

def get_closest_station(currentLat,currnetLon):
    allStations = get_all_stations()
    hPoint = geopy.Point(currentLat,currnetLon)
    data =[]
    for station in allStations:
        sPoint =geopy.Point(allStations[station]["lat"]+"/"+allStations[station]["lon"])
        distance = geopy.distance.distance(hPoint,sPoint)
        data += (distance.km,station),
        data.sort(key=lambda tup: tup[0])
    return data[0][1]
            


import io
import os
import re

from setuptools import find_packages
from setuptools import setup


def read(filename):
    filename = os.path.join(os.path.dirname(__file__), filename)
    text_type = type(u"")
    with io.open(filename, mode="r", encoding='utf-8') as fd:
        return re.sub(text_type(r':[a-z]+:`~?(.*?)`'), text_type(r'``\1``'), fd.read())


setup(
    name="meteoswiss",
    version="0.0.11",
    url="https://github.com/websylv/meteoswiss",
    license='MIT',

    author="websylv",
    author_email="div@webhu.org",

    description="Library to get data from meteo swiss",
    long_description=read("README.rst"),

    packages=find_packages(exclude=('tests',)),

    install_requires=[
        "requests>=2.22.0",
        "pandas>=0.25.3",
        "beautifulsoup4>=4.8.2",
        "geopy>=1.20.0"
    ],

    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
)



import pandas as pd

def get_current_condition(station):
    data = pd.read_csv("https://data.geo.admin.ch/ch.meteoschweiz.messwerte-aktuell/VQHA80.csv",sep=';',header=1)
    stationData = data.loc[data['stn'].str.contains(station)]
    stationData = stationData.to_dict('records')
    return stationData